==> haskell-hslua-module-doclayout-1.1.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.1.1
visibility:           public
id:                   hslua-module-doclayout-1.1.1-HgTZrksnYGg1gd0WB0nT1q
key:                  hslua-module-doclayout-1.1.1-HgTZrksnYGg1gd0WB0nT1q
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  7a63c3503c4dd59c721a14896d56bb0b
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.1-HgTZrksnYGg1gd0WB0nT1q
depends:
    base-4.17.2.1 doclayout-0.4.0.1-E7RJyZf2TcRHlrCOibxvhn
    hslua-2.3.0-28ZCoQ2UowcHlbpH2F34Gr text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-doclayout-1.1.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.1.1
visibility:           public
id:                   hslua-module-doclayout-1.1.1-50yYXVBMMwBCsqyStkJSlr
key:                  hslua-module-doclayout-1.1.1-50yYXVBMMwBCsqyStkJSlr
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  5c082e1bd183f732e815f3430f60ef2c
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.1-50yYXVBMMwBCsqyStkJSlr
depends:
    base-4.17.2.1 doclayout-0.4.0.1-EvgpMf8JUTM2oc9YMLjHdf
    hslua-2.3.0-68F8B9x7LM6K1QUr3F2bfS text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
